# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: informaticsmatters/protobuf/datamanager/instance_event_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='informaticsmatters/protobuf/datamanager/instance_event_message.proto',
  package='informaticsmatters.protobuf.datamanager',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDinformaticsmatters/protobuf/datamanager/instance_event_message.proto\x12\'informaticsmatters.protobuf.datamanager\"\x80\x01\n\x14InstanceEventMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x16\n\x0etask_record_id\x18\x02 \x01(\x03\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x1d\n\x15replace_prior_content\x18\x05 \x01(\x08\x62\x06proto3'
)




_INSTANCEEVENTMESSAGE = _descriptor.Descriptor(
  name='InstanceEventMessage',
  full_name='informaticsmatters.protobuf.datamanager.InstanceEventMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='informaticsmatters.protobuf.datamanager.InstanceEventMessage.timestamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_record_id', full_name='informaticsmatters.protobuf.datamanager.InstanceEventMessage.task_record_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='informaticsmatters.protobuf.datamanager.InstanceEventMessage.level', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='informaticsmatters.protobuf.datamanager.InstanceEventMessage.content', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replace_prior_content', full_name='informaticsmatters.protobuf.datamanager.InstanceEventMessage.replace_prior_content', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=242,
)

DESCRIPTOR.message_types_by_name['InstanceEventMessage'] = _INSTANCEEVENTMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstanceEventMessage = _reflection.GeneratedProtocolMessageType('InstanceEventMessage', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCEEVENTMESSAGE,
  '__module__' : 'informaticsmatters.protobuf.datamanager.instance_event_message_pb2'
  # @@protoc_insertion_point(class_scope:informaticsmatters.protobuf.datamanager.InstanceEventMessage)
  })
_sym_db.RegisterMessage(InstanceEventMessage)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: informaticsmatters/protobuf/datamanager/processing_cost_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='informaticsmatters/protobuf/datamanager/processing_cost_message.proto',
  package='informaticsmatters.protobuf.datamanager',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEinformaticsmatters/protobuf/datamanager/processing_cost_message.proto\x12\'informaticsmatters.protobuf.datamanager\"d\n\x15ProcessingCostMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x0c\n\x04\x63ost\x18\x02 \x01(\t\x12\x0b\n\x03sqn\x18\x03 \x01(\x03\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x0b\n\x03\x65oc\x18\x10 \x01(\x08\x62\x06proto3'
)




_PROCESSINGCOSTMESSAGE = _descriptor.Descriptor(
  name='ProcessingCostMessage',
  full_name='informaticsmatters.protobuf.datamanager.ProcessingCostMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='informaticsmatters.protobuf.datamanager.ProcessingCostMessage.timestamp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='informaticsmatters.protobuf.datamanager.ProcessingCostMessage.cost', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqn', full_name='informaticsmatters.protobuf.datamanager.ProcessingCostMessage.sqn', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance', full_name='informaticsmatters.protobuf.datamanager.ProcessingCostMessage.instance', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eoc', full_name='informaticsmatters.protobuf.datamanager.ProcessingCostMessage.eoc', index=4,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=214,
)

DESCRIPTOR.message_types_by_name['ProcessingCostMessage'] = _PROCESSINGCOSTMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessingCostMessage = _reflection.GeneratedProtocolMessageType('ProcessingCostMessage', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGCOSTMESSAGE,
  '__module__' : 'informaticsmatters.protobuf.datamanager.processing_cost_message_pb2'
  # @@protoc_insertion_point(class_scope:informaticsmatters.protobuf.datamanager.ProcessingCostMessage)
  })
_sym_db.RegisterMessage(ProcessingCostMessage)


# @@protoc_insertion_point(module_scope)
